<?php
/*
 * Copyright 2013 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// Require the base class
require_once __DIR__ . "/../BaseExample.php";

/**
 * Gets all preferred deals for the logged in user's account.
 *
 * Tags: preferreddeals.list
 *
 * @author Sérgio Gomes <sgomes@google.com>
 */
class GetAllPreferredDeals extends BaseExample {
  public function render() {
    $listClass = 'list';
    printListHeader($listClass);
    // Retrieve preferred deal list, and display it.
    $result = $this->adExchangeSellerService->preferreddeals
        ->listPreferreddeals();
    if (isset($result['items'])) {
      $deals = $result['items'];
      foreach ($deals as $deal) {
        $content = sprintf('Deal id "%s" ', $deal['id']);
        if (isset($deal['advertiserName'])) {
          $content .= sprintf('for advertiser "%s" ', $deal['advertiserName']);
        }
        if (isset($deal['buyerNetworkName'])) {
          $content .= sprintf('on network "%s" ', $deal['buyerNetworkName']);
        }
        $content .= 'was found.';
        printListElement($content);
      }
    } else {
      printNoResultForList();
    }
    printListFooter();
  }
}

