/*
 * Copyright 2012 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* Table */
table {
  border-collapse: collapse; /* Equivalent for cellspacing=0 */
}

thead tr {
  background: #eee;
  border: 1px solid #bbb;
  border-bottom: 1px solid #ccc;
}

tbody tr {
  background: #f9f9f9;
  border-bottom: 1px solid #ccc;
}

th,
td {
  padding: 5px 25px 5px 5px;
  border-left: 1px solid #ccc;
  border-right: 1px solid #ccc;
}

/* Lists */
.clients,
.list {
  border: 1px solid #e9e9e9;
  margin: 0 0 2em 0;
}

.clients li,
.list li {
  border-bottom: 1px solid #e9e9e9;
  font-size: .9em;
  background: #EEE;
  padding: 3px;
  margin: 0;
}

.clients ul,
ul.nav {
  padding: 0;
  margin: 0;
  list-style: none;
}

.clients ul li,
.nav li {
  padding: 3px;
  margin: 0 0 0 .5em;
  background: #f9f9f9;
}

a {
  font-size: .9em;
  color: black;
}

a:link,
a:active,
a:visited {
  text-decoration: none;
}

.highlight:hover {
  background: orange;
}
