/*
 * Copyright 2011 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
 
body {
  font-family:'Droid Sans', Arial;
  font-size:18px;
  background:#EEE;
  color:#444;
}
 
a {
  color:#36b;
}
 
p, h1, h3 {
  font-weight:normal;
  margin:10px 0;
  padding:0;
}
 
h1 {
  font-size:30px;
}
 
#bottom {
  width:800px;
  margin:0 auto;
}
 
#top {
  padding:2px 10px;
  font-size:14px;
  color:#fff;
  border-bottom:1px solid #000;
}
 
#top h1.logo {
  margin:6px 0;
  padding:0;
  cursor:pointer;
  font-size:24px;
  line-height:20px;
}
 
#top h1.logo a {
  color:#fff;
  text-decoration:none;
}
 
#bottom {
  padding:6px 0 6px 10px;
  font-size:11px;
  color:#aaa;
}
 
#bottom a {
  color:#333;
}
 
#top {
  color:#000;
  border:1px solid #ddd;
  border-bottom:1px solid #000;
  padding:2px 5px;
}
 
#top h1.logo a {
  color:#000;
}
 
#identity {
  display:block;
  float:right;
  padding:0;
  margin:0;
  vertical-align:super;
}
 
#identity img {
  width:28px;
  height:28px;
}

img {
  border-style:none;
} 
#content {
  padding:0;
}
 
#main {
  padding:1px 10px 1px 10px;
  margin:0;
}
 
#main h3 {
  padding:6px 0 2px 0;
  margin:0;
}

#container {
  width:990px;
  margin:0 auto;
  position:relative;
  background:white;
  border:1px solid #AAA;
  border-top:0;
  -webkit-box-shadow:#CCC 4px 0px 10px, #CCC -4px 0px 10px, #AAA 0px 38px 36px -24px;
  -moz-box-shadow:#CCC 4px 0px 10px, #CCC -4px 0px 10px, #AAA 0px 38px 36px -24px;
  box-shadow:#CCC 4px 0px 10px, #CCC -4px 0px 10px, #AAA 0px 38px 36px -24px;
  overflow:hidden;
}

#image {
  background:white;
  border:1px solid #2276BB;
  display:block;
  float:left;
  margin:0 10px 10px 0;
  overflow:hidden;
}

#task {
  background:white;
  border:1px solid #999;
  clear:left;
  font-size:1.2em;
  margin-bottom:5px;
  padding:8px;
  -moz-border-radius:5px;
  -webkit-border-radius:5px;
}
