/*
 * Copyright 2011 Google Inc.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

body {
  font-family: Arial,sans-serif;
  margin: auto;
  white-space: nowrap;
}

.box {
  border: .5em solid #E3E9FF;
  -webkit-box-orient: vertical;
  -webkit-box-align: center;

  -moz-box-orient: vertical;
  -moz-box-align: center;

  display: block;
  box-orient: vertical;
  box-align: center;

  width: 400px;
  height: auto;

  margin: auto;
  padding: 10px;
}

.request {
  -webkit-box-flex: 1;
  -moz-box-flex: 1;
  box-flex: 1;
}

.result {
  -webkit-box-flex: 2;
  -moz-box-flex: 2;
  box-flex: 2;
}

header {
  color:#000;
  padding:2px 5px;
  font-size:100%;
  margin: auto;
  text-align: center
}

header h1.logo {
  margin:6px 0;
  padding:0;
  font-size:24px;
  line-height:20px;
  text-align: center
}

.login {
  font-size: 200%;
  display: block;
  margin: auto;
  cursor: pointer;
  text-align: center;
  font-weight: bold;
  color: #2779AA;
  line-height: normal;
}

.logout {
  font-weight: normal;
  margin-top: 0;
}

.url {
  color: #019;
  font-size: 100%;
  vertical-align: middle;
  padding: 1px;
  background-color: white;
  border: 1px inset;
  cursor: auto;
  margin: 0;
  text-indent: 0;
  display: inline-block;
}