body {
  background-color: white;
  color: black;
  font-family: Arial, sans-serif;
  font-size: small;
  margin: 8px;
  margin-top: 3px;
}

.thumbnail img {
  border-color:black;
  border-style:solid;
}

table {
  border-collapse: collapse;
}

th, td {
  padding: 0;
  vertical-align: top;
  text-align: left;
  font-size: small;
}

a:link {
  color: #0000cc;
}

a:active {
  color: #cc0000;
}

a:visited {
  color: #551a8b;
}

h1 {
  font-size: x-large;
  margin-top: 0px;
  margin-bottom: 5px;
}

h2 {
  font-size: large;
}

form {
  display: inline;
  margin: 0;
  padding: 0;
}

.volumeList td {
  padding-bottom: 5px;
  padding-right: 5px;
}

#titleBar {
  border: 1px solid silver;
  background-color: #e5ecf9;
  font-size: large;
  font-weight: bold;
  margin: 0;
  padding: 0;
  padding-top: 5px;
  padding-bottom: 10px;
  padding-left: 10px;
  padding-right: 10px;
  margin-top: 5px;
  margin-bottom: 15px;
}

#titleText {
  float: left;
}

#mainSearchBox {
  background-color: #e5ecf9;
  border: 1px solid silver;
  width: 300;
  padding-top: 5px;
  padding-bottom: 10px;
  padding-left: 10px;
  padding-right: 10px;
}

#searchResults {
  width: 100%;
}

.volumeList td
{
  border-top: 1px solid #aaaaaa;
  padding: 6px;
}

.thumbnail
{
  height: 80px;
  padding: 3px;
}

.previewbutton
{
  border: 0px;
  margin: 6px 0px 6px 0px;
}

#resultcell
{
  padding-right: 20px;
}

#previewcell
{
  border-left: 1px dotted #aaa;
  padding-left: 20px;
  display: none;
  padding-right: 20px;
}

#viewport {
  height: 500px;
  width: 100%;
  border: 1px solid #aaa;
}

/* Google Preview: Boilerplate styling */
#viewport { font-size: 16px; line-height: 1; }
#viewport img, #viewport table, #viewport div, #viewport td
{ border: 0;  padding: 0; margin: 0; background: none }
#viewport td { vertical-align: middle }